using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Microsoft.HomeServer.Extensibility;
using Microsoft.HomeServer.Controls;
using Microsoft.HomeServer.Common.Client;

namespace Microsoft.HomeServer.HomeServerConsoleTab.MessageListBoxDemoCS
{
   public partial class MainTabUserControl : UserControl
   {
      IConsoleServices consoleServices;

      public MainTabUserControl()
      {
         InitializeComponent();
      }

      public MainTabUserControl(int width, int height, IConsoleServices consoleServices)
         : this()
      {
         this.Width = width;
         this.Height = height;
         this.consoleServices = consoleServices;
      }

      private void MainTabUserControl_Load(object sender, EventArgs e)
      {
         //Create item
         MessageListBoxItem redItem = new MessageListBoxItem(Color.Red);
         //Set bold title text
         redItem.Title = "Big ole problem";
         //Set body text
         redItem.Description.Text = "Important information on the specifics of this error goes here.";
         //Set icon
         redItem.Icon = CommonImages.StatusCritical24Icon;
         //Specify text of button (to make visible)
         redItem.ActionButton.Text = "Fix Error";
         //Add event handler for button
         redItem.ActionButton.Click += new EventHandler(ActionButton_Click);
         //Add MessageListBoxItem to MessageListBox
         messageListBox1.Items.Add(redItem);


         //Create item
         MessageListBoxItem yellowItem = new MessageListBoxItem(Color.Yellow);
         //Set bold title text
         yellowItem.Title = "Minor issue";
         //Set body text
         yellowItem.Description.Text = "The world is going to end... just not today.";
         //Set icon
         yellowItem.Icon = CommonImages.StatusAtRisk24Icon;
         //Backup current color for use in event handler
         yellowItem.Tag = yellowItem.GradientColor;
         //Specify text for CheckBox
         yellowItem.CheckBox.Text = "Ignore this";
         //Make CheckBox visible
         yellowItem.CheckBox.Visible = true;
         //Add event handler
         yellowItem.CheckBox.CheckedChanged += new EventHandler(CheckBox_CheckedChanged);
         //Add MessageListBoxItem to MessageListBox
         messageListBox1.Items.Add(yellowItem);
         
         
         //Create item
         MessageListBoxItem greenItem = new MessageListBoxItem(Color.Green);
         //Set bold title text
         greenItem.Title = "All is well";
         //Set body text
         greenItem.Description.Text = "Pay no attention to the man behind the curtain.\nClick here for more information";
         //Set icon
         greenItem.Icon = CommonImages.StatusHealthy24Icon;
         //Link starts on 48th character and is 31 character long
         greenItem.Description.LinkArea = new LinkArea(48, 31);
         //Add event handler
         greenItem.Description.LinkClicked += new LinkLabelLinkClickedEventHandler(Description_LinkClicked);
         //Add MessageListBoxItem to MessageListBox
         messageListBox1.Items.Add(greenItem);



         //Create extra item to show off ugliness of having both a button and CheckBox on a single item
         MessageListBoxItem uglyYellowItem = new MessageListBoxItem(Color.Yellow);
         //Set bold title text
         uglyYellowItem.Title = "Minor issue";
         //Set body text
         uglyYellowItem.Description.Text = "The world is going to end... just not today.";
         //Set icon
         uglyYellowItem.Icon = CommonImages.StatusAtRisk24Icon;
         
         //Backup current color for use in event handler
         uglyYellowItem.Tag = uglyYellowItem.GradientColor;
         //Specify text for CheckBox
         uglyYellowItem.CheckBox.Text = "Ignore this";
         //Make CheckBox visible
         uglyYellowItem.CheckBox.Visible = true;
         //Add event handler
         uglyYellowItem.CheckBox.CheckedChanged += new EventHandler(CheckBox_CheckedChanged);

         //Specify text of button (to make visible)
         uglyYellowItem.ActionButton.Text = "Fix Error";
         //Add event handler for button
         uglyYellowItem.ActionButton.Click += new EventHandler(ActionButton_Click);

         //Add MessageListBoxItem to MessageListBox
         messageListBox1.Items.Add(uglyYellowItem);
      }

      void ActionButton_Click(object sender, EventArgs e)
      {
         //Determine which button was clicked
         Button b = sender as Button;
         //Determine which MessageListBoxItem the button exists on
         MessageListBoxItem mlbi = b.Parent as MessageListBoxItem;

         //Do useful processing

         //Remove specified MessageListBoxItem from MessageListBox
         messageListBox1.Items.Remove(mlbi);
      }

      void CheckBox_CheckedChanged(object sender, EventArgs e)
      {
         //Determine which CheckBox was checked
         CheckBox cb = sender as CheckBox;
         ////Determine which MessageListBoxItem the CheckBox exists on
         MessageListBoxItem mlbi = cb.Parent as MessageListBoxItem;

         //Has the checkbox been unchecked? Undo changes and restore color to original
         if (!mlbi.CheckBox.Checked)
         {
            //Do useful processing
            mlbi.GradientColor = (Color)mlbi.Tag;
         }
         else // Else do disabling work and set color to Gray
         {
            //Do useful processing
            mlbi.GradientColor = Color.Gray;
         }
      }

      void Description_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
      {
         //Do something based on link

         QMessageBox.Show("Link Clicked", "Link Clicked");
      }

      private void addCriticalItemButton_Click(object sender, EventArgs e)
      {
         //Create item
         MessageListBoxItem redItem = new MessageListBoxItem(Color.Red);
         //Set bold title text
         redItem.Title = "Big ole problem";
         //Set body text
         redItem.Description.Text = "Important information on the specifics of this error goes here.";
         //Set icon
         redItem.Icon = CommonImages.StatusCritical24Icon;
         //Specify text of button (to make visible)
         redItem.ActionButton.Text = "Fix Error";
         //Add event handler for button
         redItem.ActionButton.Click += new EventHandler(ActionButton_Click);
         //Add MessageListBoxItem to MessageListBox
         messageListBox1.Items.Add(redItem);
      }
   }
}
